<?xml version="1.0"?>
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
               version="2.0"
               xmlns:xlf="urn:oasis:names:tc:xliff:document:1.1"
               xmlns:dita="dita"
               xmlns:xmrk="www.xmarker.com">
<xsl:output method="xml" indent="yes" encoding="utf-8" />


<xsl:strip-space elements="*" />

<xsl:template match="node()|@*">
 <xsl:copy>
  <xsl:apply-templates select="@*|node()"/>
 </xsl:copy>
</xsl:template>

<xsl:template match="xlf:file" priority="3">
<!--
 <xsl:result-document
  href="{substring-after(@original,'/')}">
-->
 <xsl:result-document
  href="{concat('xlated-',@original)}">
   <xsl:element name="{xlf:body/xlf:group[1]/@resname}">
    <xsl:for-each select="xlf:body/xlf:group[1]/@*[name()!='resname'][name()!='id'][name()!='ctype'][local-name()!='rootname'][local-name()!='ancs'][local-name()!='datatype'][local-name()!='source-language']">
     <xsl:attribute name="{local-name()}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <xsl:apply-templates />
   </xsl:element>
 </xsl:result-document>
</xsl:template>

<xsl:template match="*[local-name()='body']/xlf:group[count(preceding-sibling::*)=0]" priority="4">
</xsl:template>

<xsl:template match="xlf:group[@*[local-name()='one']]" priority="4">
    <xsl:apply-templates />
</xsl:template>

<xsl:template match="xlf:group[@resname]" priority="3">
 <xsl:variable name="resname" select="@resname" />
 <xsl:variable name="ancs" select="@*[local-name()='ancs']" />
 <xsl:choose>
  <xsl:when test="child::xlf:group/@resname=$resname and child::xlf:group/@*[local-name()='ancs']=$ancs">
   <xsl:apply-templates />
  </xsl:when>
  <xsl:when test="child::xlf:trans-unit/@resname=$resname and child::xlf:trans-unit/@*[local-name()='ancs']=$ancs">
   <xsl:apply-templates />
  </xsl:when>
  <xsl:otherwise>
   <xsl:element name="{@resname}">
    <xsl:for-each select="@*[name()!='resname'][name()!='id'][name()!='ctype'][local-name()!='ancs']">
     <xsl:attribute name="{local-name()}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <xsl:apply-templates />
   </xsl:element>
  </xsl:otherwise>
 </xsl:choose>
</xsl:template>

<xsl:template match="xlf:trans-unit[@resname]" priority="3">
 <xsl:element name="{@resname}">
  <xsl:for-each select="@*[name()!='resname'][name()!='id'][name()!='ctype'][local-name()!='ancs']">
   <xsl:attribute name="{local-name()}">
    <xsl:value-of select="." />
   </xsl:attribute>
  </xsl:for-each>
  <xsl:apply-templates select="xlf:target"/>
 </xsl:element>
</xsl:template>

<xsl:template match="xlf:g">
 <xsl:element name="{substring-after(@ctype,'x-')}">
  <xsl:for-each select="@*[name()!='resname'][name()!='id'][name()!='ctype'][local-name()!='ancs']">
   <xsl:attribute name="{local-name()}">
    <xsl:value-of select="." />
   </xsl:attribute>
  </xsl:for-each>
  <xsl:apply-templates />
 </xsl:element>
</xsl:template>

<xsl:template match="xlf:x | x">
 <xsl:element name="{substring-before(@id,'-x-mch')}">
  <xsl:for-each select="@*[name()!='resname'][name()!='id'][name()!='ctype'][local-name()!='ancs']">
   <xsl:attribute name="{local-name()}">
    <xsl:value-of select="." />
   </xsl:attribute>
  </xsl:for-each>
  <xsl:apply-templates />
 </xsl:element>
</xsl:template>

<xsl:template match="*[namespace-uri()='www.xmarker.com']">
 <xsl:element name="{@ctype}">
  <xsl:for-each select="@*[name()!='resname'][name()!='id'][name()!='ctype'][local-name()!='ancs']">
   <xsl:attribute name="{local-name()}">
    <xsl:value-of select="." />
   </xsl:attribute>
  </xsl:for-each>
  <xsl:apply-templates />
 </xsl:element>
</xsl:template>

<xsl:template match="xlf:xliff | 
                     xlf:file | 
                     xlf:group | 
                     xlf:body | 
                     xlf:trans-unit | 
                     xlf:target">
  <xsl:apply-templates />
</xsl:template>


<xsl:template match="xlf:source" />

</xsl:transform>
