<?xml version="1.0"?>
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
               xmlns:xmrk="http://www.xmarker.com"
               version="2.0">

<xsl:output method="xml" indent="yes" encoding="utf-8" />

<xsl:strip-space elements="*" />

<!--
<xsl:when test="substring-after(substring-before($,''),'')">
-->

<xsl:template match="map" priority="8">
 <xliff  
        xmlns="urn:oasis:names:tc:xliff:document:1.1" 
        xmlns:xmrk="http://www.xmarker.com" 
        xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
        xsi:schemaLocation="urn:oasis:names:tc:xliff:document:1.1          
        xliff-1.1.xsd" version="1.1">
  <xsl:apply-templates select="//topicref"/>
 </xliff>
</xsl:template>

<xsl:template match="map//topicref" priority="8">
 <xsl:variable name="path" select="@href" />
 <file datatype="xml" xmlns="urn:oasis:names:tc:xliff:document:1.1"
       original="{$path}" 
       level="{local-name(ancestor::*[1])}" 
       order="{count(preceding-sibling::*)+1}" 
       source-language="en_US" 
       target-language="dumme Sprache"
       tool="xliffRoundTrip Tool (Schnabel DITA prototype)">
   <xsl:for-each select="@*">
    <xsl:attribute name="{concat('xmrk:',name())}">
     <xsl:value-of select="." />
    </xsl:attribute>
   </xsl:for-each>
    <body xmlns="urn:oasis:names:tc:xliff:document:1.1">
     <xsl:for-each select="document($path)/*[count(ancestor::*)=0]">
      <group resname="{local-name()}" xmlns="urn:oasis:names:tc:xliff:document:1.1"
             xmrk:rootname="{local-name(document($path)/*[count(ancestor::*)=0])}">
       <xsl:for-each select="@*">
        <xsl:attribute name="{concat('xmrk:',local-name())}">
         <xsl:value-of select="." />
         <xsl:if test="string-length(namespace-uri())&gt;2">
          <xsl:value-of select="concat('-',namespace-uri())" />
         </xsl:if>
        </xsl:attribute>
       </xsl:for-each>
      </group>
     </xsl:for-each>

    <xsl:variable name="ancestors" select="count(ancestor::*)" />
     <group resname="{name()}" xmlns="urn:oasis:names:tc:xliff:document:1.1" 
            xmrk:ancs="{$ancestors}" xmrk:one="1">
      <xsl:for-each select="@*">
       <xsl:attribute name="{concat('xmrk:',name())}">
        <xsl:value-of select="." />
       </xsl:attribute>
      </xsl:for-each>
       <xsl:apply-templates select="document($path)" />
     </group>
    </body>
 </file>
</xsl:template>

<!-- copy from xliffRoundTrip Tool -->

<xsl:template match="*[count(ancestor::*)>0][not(ancestor::*[text()])][child::*]" priority="5"><!-- remember to change from string to integer for XSLT 2.0 -->
 <xsl:variable name="ancestors" select="count(ancestor::*)" />
 <group resname="{name()}" xmlns="urn:oasis:names:tc:xliff:document:1.1" xmrk:ancs="{$ancestors}">
  <xsl:for-each select="@*">
   <xsl:attribute name="{concat('xmrk:',name())}">
    <xsl:value-of select="." />
   </xsl:attribute>
  </xsl:for-each>
  <xsl:call-template name="inner" />
 </group>
</xsl:template>

<!--
 note: must keep this named template,
       and the following match template
       exactly in synch
-->

<xsl:template name="inner">
 <xsl:variable name="ancestors" select="count(ancestor::*)" />
 <xsl:choose>
<!-- has text, parent has text-->
  <xsl:when test="text() and parent::*[text()]">
   <g id="{concat(name(),'-x-',generate-id())}" xmrk:ancs="{$ancestors}" ctype="{concat('x-',name())}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
<!-- put tracers here, if necessary
    <xsl:if test="count(parent::*/text())='1' and preceding-sibling::text()">
    </xsl:if>
    <xsl:if test="count(parent::*/text())='1' and following-sibling::text()">
    </xsl:if>
    <xsl:if test="count(parent::*/text())>'1'">
    </xsl:if>
-->
    <xsl:apply-templates />
   </g>
  </xsl:when>
<!-- has text, ancestor has no text -->
  <xsl:when test="text() and not(ancestor::*[text()])">
   <trans-unit resname="{name()}" id="{concat(name(),'-x-',generate-id())}" xmlns="urn:oasis:names:tc:xliff:document:1.1" xmrk:ancs="{$ancestors}">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <source xmrk:ancs="{$ancestors}">
     <xsl:apply-templates />
    </source>
    <target>
     <xsl:apply-templates />
    </target>
   </trans-unit>
  </xsl:when>
<!-- has text, ancestor has text -->
  <xsl:when test="text() and ancestor::*[text()]">
   <g id="{concat(name(),'-x-',generate-id())}" ctype="{concat('x-',name())}" xmlns="urn:oasis:names:tc:xliff:document:1.1" xmrk:ancs="{$ancestors}">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
     <xsl:apply-templates />
   </g>
  </xsl:when>
<!-- has no text, ancestor has no text -->
  <xsl:when test="not(text()) and not(ancestor::*[text()]) and child::*">
    <group id="{concat('throw1-',generate-id())}" xmrk:ancs="{$ancestors}" resname="{name()}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
     <xsl:for-each select="@*">
      <xsl:attribute name="{concat('xmrk:',name())}">
       <xsl:value-of select="." />
      </xsl:attribute>
     </xsl:for-each>
     <xsl:apply-templates />
    </group>
  </xsl:when>
<!-- has no text, ancestor has text -->
  <xsl:when test="not(text()) and ancestor::*[text()] and child::*">
    <g id="{concat('throw2-',generate-id())}" xmrk:ancs="{$ancestors}" ctype="{concat('x-',name())}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
     <xsl:for-each select="@*">
      <xsl:attribute name="{concat('xmrk:',name())}">
       <xsl:value-of select="." />
      </xsl:attribute>
     </xsl:for-each>
     <xsl:apply-templates />
    </g>
  </xsl:when>
<!-- has no text, has child, parent has text -->
  <xsl:when test="not(text()) and parent::*[text()] and child::*">
   <g id="{concat(name(),'-mch3-',generate-id())}" xmrk:ancs="{$ancestors}" ctype="{concat('x-',name())}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <xsl:apply-templates />
   </g>
  </xsl:when>
<!-- has no text, has no child, parent has text -->
  <xsl:when test="not(text()) and parent::*[text()] and not(child::*)">
   <x id="{concat(name(),'-x-mch1-',generate-id())}" xmrk:ancs="{$ancestors}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <xsl:apply-templates />
   </x>
  </xsl:when>
<!-- has no text, has no child, ancestor has no text -->
  <xsl:when test="not(text()) and not(ancestor::*[text()]) and not(child::*)">
   <group id="slllp2" xmlns="urn:oasis:names:tc:xliff:document:1.1" xmrk:ancs="{$ancestors}">
    <trans-unit id="{generate-id()}">
     <source>
      <x id="{concat(name(),'-x-mch2-',generate-id())}" xmrk:ancs="{$ancestors}">
       <xsl:for-each select="@*">
        <xsl:attribute name="{concat('xmrk:',name())}">
         <xsl:value-of select="." />
        </xsl:attribute>
       </xsl:for-each>
       <xsl:apply-templates />
      </x>
     </source>
     <target id="{generate-id()}">
      <x id="{concat(name(),'-x-mch2-',generate-id())}" xmrk:ancs="{$ancestors}">
       <xsl:for-each select="@*">
        <xsl:attribute name="{concat('xmrk:',name())}">
         <xsl:value-of select="." />
        </xsl:attribute>
       </xsl:for-each>
       <xsl:apply-templates />
      </x>
     </target>
    </trans-unit>
   </group>
  </xsl:when>
<!-- has no text, has no child, ancestor has text -->
  <xsl:when test="not(text()) and ancestor::*[text()] and not(child::*)">
      <x id="{concat(name(),'-x-mch2-',generate-id())}" xmrk:ancs="{$ancestors}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
       <xsl:for-each select="@*">
        <xsl:attribute name="{concat('xmrk:',name())}">
         <xsl:value-of select="." />
        </xsl:attribute>
       </xsl:for-each>
       <xsl:apply-templates />
      </x>
  </xsl:when>
  <xsl:otherwise>
   <blip was="{name()}" ancs="{$ancestors}">
    <xsl:apply-templates />
   </blip>
  </xsl:otherwise>
 </xsl:choose>
</xsl:template>


<xsl:template match="*[count(ancestor::*)>0]"><!-- remember to change from string to integer for XSLT 2.0 -->
 <xsl:variable name="ancestors" select="count(ancestor::*)" />
 <xsl:choose>
<!-- has text, parent has text-->
  <xsl:when test="text() and parent::*[text()]">
   <g id="{concat(name(),'-x-',generate-id())}" xmrk:ancs="{$ancestors}" ctype="{concat('x-',name())}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <xsl:apply-templates />
   </g>
  </xsl:when>
<!-- has text, ancestor has no text -->
  <xsl:when test="text() and not(ancestor::*[text()])">
   <trans-unit resname="{name()}" id="{concat(name(),'-x-mch1-',generate-id())}" xmlns="urn:oasis:names:tc:xliff:document:1.1" xmrk:ancs="{$ancestors}">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <source xmrk:ancs="{$ancestors}">
     <xsl:apply-templates />
    </source>
    <target>
     <xsl:apply-templates />
    </target>
   </trans-unit>
  </xsl:when>
<!-- has text, ancestor has text -->
  <xsl:when test="text() and ancestor::*[text()]">
   <g ctype="{concat('x-',name())}" id="{concat(name(),'-x-mch1-',generate-id())}" xmlns="urn:oasis:names:tc:xliff:document:1.1" xmrk:ancs="{$ancestors}">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
     <xsl:apply-templates />
   </g>
  </xsl:when>
<!-- has no text, ancestor has no text -->
  <xsl:when test="not(text()) and not(ancestor::*[text()]) and child::*">
    <group id="{concat('throw-',generate-id())}" xmrk:ancs="{$ancestors}" resname="{name()}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
     <xsl:for-each select="@*">
      <xsl:attribute name="{concat('xmrk:',name())}">
       <xsl:value-of select="." />
      </xsl:attribute>
     </xsl:for-each>
     <xsl:apply-templates />
    </group>
  </xsl:when>
<!-- has no text, ancestor has text -->
  <xsl:when test="not(text()) and ancestor::*[text()] and child::*">
    <g id="{concat('throw1-',generate-id())}" xmrk:ancs="{$ancestors}" ctype="{concat('x-',name())}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
     <xsl:for-each select="@*">
      <xsl:attribute name="{concat('xmrk:',name())}">
       <xsl:value-of select="." />
      </xsl:attribute>
     </xsl:for-each>
     <xsl:apply-templates />
    </g>
  </xsl:when>
<!-- has no text, has child, parent has text -->
  <xsl:when test="not(text()) and parent::*[text()] and child::*">
   <g id="{concat(name(),'-mch3-',generate-id())}" xmrk:ancs="{$ancestors}" ctype="{concat('x-',name())}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <xsl:apply-templates />
   </g>
  </xsl:when>
<!-- has no text, has no child, parent has text -->
  <xsl:when test="not(text()) and parent::*[text()] and not(child::*)">
   <x id="{concat(name(),'-x-mch1-',generate-id())}" xmrk:ancs="{$ancestors}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
    <xsl:for-each select="@*">
     <xsl:attribute name="{concat('xmrk:',name())}">
      <xsl:value-of select="." />
     </xsl:attribute>
    </xsl:for-each>
    <xsl:apply-templates />
   </x>
  </xsl:when>
<!-- has no text, has no child, ancestor has no text -->
  <xsl:when test="not(text()) and not(ancestor::*[text()]) and not(child::*)">
   <group id="slllp2" xmlns="urn:oasis:names:tc:xliff:document:1.1" xmrk:ancs="{$ancestors}">
    <trans-unit id="{generate-id()}" xmrk:ancs="{$ancestors}">
     <source>
      <x id="{concat(name(),'-x-mch2-',generate-id())}" xmrk:ancs="{$ancestors}">
       <xsl:for-each select="@*">
        <xsl:attribute name="{concat('xmrk:',name())}">
         <xsl:value-of select="." />
        </xsl:attribute>
       </xsl:for-each>
       <xsl:apply-templates />
      </x>
     </source>
     <target>
      <x id="{concat(name(),'-x-mch2-',generate-id())}" xmrk:ancs="{$ancestors}">
       <xsl:for-each select="@*">
        <xsl:attribute name="{concat('xmrk:',name())}">
         <xsl:value-of select="." />
        </xsl:attribute>
       </xsl:for-each>
       <xsl:apply-templates />
      </x>
     </target>
    </trans-unit>
   </group>
  </xsl:when>
<!-- has no text, has no child, ancestor has text -->
  <xsl:when test="not(text()) and ancestor::*[text()] and not(child::*)">
      <x id="{concat(name(),'-x-mch2-',generate-id())}" xmrk:ancs="{$ancestors}" xmlns="urn:oasis:names:tc:xliff:document:1.1">
       <xsl:for-each select="@*">
        <xsl:attribute name="{concat('xmrk:',name())}">
         <xsl:value-of select="." />
        </xsl:attribute>
       </xsl:for-each>
       <xsl:apply-templates />
      </x>
  </xsl:when>
  <xsl:otherwise>
   <blip was="{name()}" ancs="{$ancestors}">
    <xsl:apply-templates />
   </blip>
  </xsl:otherwise>
 </xsl:choose>
</xsl:template>

</xsl:transform>
